"use strict";
var crypto_1 = require("crypto");
var server_1 = require("../server");
var schema_1 = require("./schema");
module.exports = function (server) {
    var protocol = new server_1.MuServerRPC(server, schema_1.RPCSchema);
    protocol.configure({
        // functions to be executed by RPCs from client go into `rpc`
        rpc: {
            // argument supplied by RPCs is available as the first argument
            hash: function (secret, next) {
                var digest = crypto_1.createHash('sha512').update(secret).digest('hex');
                // call `next()` when any exceptions occur or after having the return
                // when there is an exception, call `next()` with the error message:
                // next(errorMessage)
                // otherwise, always pass `undefined` as the first argument,
                // and return value as the second, as below
                // in this case, value of `digest` should match RPCSchema['server']['hash'][1]
                next(undefined, digest);
            }
        },
        // when client connects
        connect: function (client) {
            var set = [1, 2, 3, 4];
            // initiates a RPC of `sum()` to client
            // value of `set` is sent to client as argument of the remote `sum()`
            // its value should match RPCSchema['client']['sum'][0]
            // second argument is a callback called when return value arrives,
            // which is available as second argument of the callback
            // so `total` is the sum of `set`
            client.rpc.sum(set, function (err, total) {
                if (err) {
                    throw new Error(err);
                }
                console.log("sum of " + set + ": " + total);
            });
        }
    });
    // start server after configuring all server-side protocols
    server.start();
};
